@@ -1,6 +1,6 @@
 /*
  * check_dir.h
- * Copyright (c) 2ndQuadrant, 2010-2014
+ * Copyright (c) 2ndQuadrant, 2010-2015
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,11 +20,11 @@
 #ifndef _REPMGR_CHECK_DIR_H_
 #define _REPMGR_CHECK_DIR_H_
 
-int mkdir_p(char *path, mode_t omode);
-int  check_dir(char *dir);
-bool create_directory(char *dir);
-bool set_directory_permissions(char *dir);
-bool is_pg_dir(char *dir);
-bool create_pgdir(char *dir, bool force);
+int			mkdir_p(char *path, mode_t omode);
+int			check_dir(char *dir);
+bool		create_dir(char *dir);
+bool		set_dir_permissions(char *dir);
+bool		is_pg_dir(char *dir);
+bool		create_pg_dir(char *dir, bool force);
 
 #endif
